@@ -53,7 +53,7 @@ setOldClass("Kriging")
 #' @slot Kriging A copy of the \code{Kriging} object used to create
 #'     the current \code{KM} object.
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @name KM-class
 #' @rdname KM-class
@@ -76,7 +76,7 @@ setClass("KM", slots = c("Kriging" = "Kriging"), contains = "km")
 #'
 #' @title Create an \code{KM} Object
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param formula R formula object to setup the linear trend in
 #'     Universal Kriging. Supports \code{~ 1}, ~. and \code{~ .^2}.
@@ -196,17 +196,17 @@ KM <- function(formula = ~1, design, response,
     
     parameters <- list()
     if (!is.null(coef.var))
-        parameters <- c(parameters, list(sigma2 = coef.var))
+        parameters <- c(parameters, list(sigma2 = coef.var, is_sigma2_estim=FALSE))
     if (!is.null(coef.cov)) {
         parameters <- c(parameters,
-                        list(theta = matrix(coef.cov, ncol = ncol(design))))
+                        list(theta = matrix(coef.cov, ncol = ncol(design)), is_theta_estim=FALSE))
         optim.method <- "none"
         ## XXXY 
         warning("Since 'coef.cov' is provided 'optim.method' is set to ",
                 "\"none\"")
     }  
     if (!is.null(coef.trend)) {
-        parameters <- c(parameters, list(beta = matrix(coef.trend)))
+        parameters <- c(parameters, list(beta = matrix(coef.trend), is_beta_estim=FALSE))
     }
     if (!is.null(parinit)) {
         parameters <- c(parameters,
@@ -258,7 +258,7 @@ predict.KM <- function(object, newdata, type = "UK",
     if (type != "UK") stop("'type != UK' unsupported.")
     
     y.predict <- predict.Kriging(object@Kriging, x = newdata,
-                                 stdev = se.compute, cov = cov.compute)
+                                 return_stdev = se.compute, return_cov = cov.compute)
     
     output.list <- list()
     ## output.list$trend <- y.predict.trend
@@ -301,7 +301,7 @@ predict.KM <- function(object, newdata, type = "UK",
 #' 
 #' @title Prediction Method for a \code{KM} Object
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param object \code{KM} object.
 #' @param newdata Matrix of "new" input points where to perform
@@ -363,7 +363,7 @@ simulate.KM <- function(object, nsim = 1, seed = NULL, newdata,
   if (nugget.sim!=0) stop("'nugget.sim != 0' unsupported.")
   
   return(simulate.Kriging(object = object@Kriging,
-                          x = newdata,nsim = nsim, seed = seed))
+                          x = newdata, nsim = nsim, seed = seed))
 }
 
 ## *****************************************************************************
@@ -379,7 +379,7 @@ simulate.KM <- function(object, nsim = 1, seed = NULL, newdata,
 #'
 #' @title Simulation from a \code{KM} Object
 #' 
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param object A \code{KM} object.
 #'
@@ -475,7 +475,7 @@ update.KM <- function(object,
 #'
 #' @title Update a \code{KM} Object with New Points
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #' 
 #' @param object A KM object.
 #' @param newX A numeric matrix containing the new design points. It
@@ -531,7 +531,7 @@ update.KM <- function(object,
 #' points(newX, newy, col = "red")
 #' 
 #' ## replace the object by its udated version
-#' KMobj <- update(KMobj, newy, newX)
+#' KMobj <- update(KMobj, newX=newX, newy=newy)
 #'
 #' x <- seq(from = 0, to = 1, length.out = 101)
 #' p2_x <- predict(KMobj, x)
