@@ -32,7 +32,7 @@ classNoiseKriging <- function(nk) {
 #' are estimated thanks to the optimization of a criterion given by
 #' \code{objective}, using the method given in \code{optim}.
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param y Numeric vector of response values.
 #' @param noise Numeric vector of response variances.
@@ -116,7 +116,7 @@ NoiseKriging <- function(y=NULL, noise=NULL, X=NULL, kernel=NULL,
 
 #' Coerce a \code{NoiseKriging} Object into a List
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param x An object with class \code{"NoiseKriging"}.
 #' @param ... Ignored
@@ -151,7 +151,7 @@ as.list.NoiseKriging <- function(x, ...) {
 #' Coerce a \code{NoiseKriging} object into the \code{"km"} class of the
 #' \pkg{DiceKriging} package.
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param x An object with S3 class \code{"NoiseKriging"}.
 #' @param .call Force the \code{call} slot to be filled in the
@@ -263,7 +263,7 @@ as.km.NoiseKriging <- function(x, .call = NULL, ...) {
 
 #' Print the content of a \code{NoiseKriging} object.
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param x A (S3) \code{NoiseKriging} Object.
 #' @param ... Ignored.
@@ -298,7 +298,7 @@ print.NoiseKriging <- function(x, ...) {
 #' are estimated thanks to the optimization of a criterion given by
 #' \code{objective}, using the method given in \code{optim}.
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object S3 NoiseKriging object.
 #' @param y Numeric vector of response values.
@@ -373,7 +373,7 @@ fit.NoiseKriging <- function(object, y, noise, X,
 #' stochastic process, conditional on the values at the input points
 #' used when fitting the model.
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object S3 NoiseKriging object.
 #' @param x Input points where the prediction must be computed.
@@ -416,13 +416,9 @@ fit.NoiseKriging <- function(object, y, noise, X,
 #'  border = NA, col = rgb(0, 0, 1, 0.2))
 predict.NoiseKriging <- function(object, x, return_stdev = TRUE, return_cov = FALSE, return_deriv = FALSE, ...) {
     if (length(L <- list(...)) > 0) warnOnDots(L)
-    k <- noisekriging_model(object)
     ## manage the data frame case. Ideally we should then warn
     if (is.data.frame(x)) x = data.matrix(x)
-    if (!is.matrix(x)) x=matrix(x,ncol=ncol(k$X))
-    if (ncol(x) != ncol(k$X))
-        stop("Input x must have ", ncol(k$X), " columns (instead of ",
-             ncol(x), ")")
+    if (!is.matrix(x)) x=matrix(x,ncol=ncol(object$X()))
     return(noisekriging_predict(object, x, return_stdev, return_cov, return_deriv))
 }
 
@@ -433,7 +429,7 @@ predict.NoiseKriging <- function(object, x, return_stdev = TRUE, return_cov = FA
 #' points conditional on the values at the input points used in the
 #' fit.
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object S3 NoiseKriging object.
 #' @param nsim Number of simulations to perform.
@@ -476,12 +472,9 @@ predict.NoiseKriging <- function(object, x, return_stdev = TRUE, return_cov = FA
 #' lines(x, s[ , 3], col = "blue")
 simulate.NoiseKriging <- function(object, nsim = 1, seed = 123, x, with_noise = NULL, will_update = FALSE,  ...) {
     if (length(L <- list(...)) > 0) warnOnDots(L)
-    k <- noisekriging_model(object)
+    ## manage the data frame case. Ideally we should then warn
     if (is.data.frame(x)) x = data.matrix(x)
-    if (!is.matrix(x)) x = matrix(x, ncol = ncol(k$X))
-    if (ncol(x) != ncol(k$X))
-        stop("Input x must have ", ncol(k$X), " columns (instead of ",
-             ncol(x),")")
+    if (!is.matrix(x)) x=matrix(x,ncol=ncol(object$X()))
     if (is.null(seed)) seed <- floor(runif(1) * 99999)
     if (is.null(with_noise) || isFALSE(with_noise)) with_noise = rep(0, nrow(x))
     return(noisekriging_simulate(object, nsim = nsim, seed = seed, X_n = x, with_noise = with_noise, will_update = will_update))
@@ -492,7 +485,7 @@ simulate.NoiseKriging <- function(object, nsim = 1, seed = 123, x, with_noise =
 #' This method draws paths of the stochastic process conditional on the values at the input points used in the
 #' fit, plus the new input points and their values given as argument (knonw as 'update' points).
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object S3 NoiseKriging object.
 #' @param y_u Numeric vector of new responses (output).
@@ -535,24 +528,17 @@ simulate.NoiseKriging <- function(object, nsim = 1, seed = 123, x, with_noise =
 #' lines(x, su[ , 3], col = "blue", lty=2)
 update_simulate.NoiseKriging <- function(object, y_u, noise_u, X_u, ...) {
     if (length(L <- list(...)) > 0) warnOnDots(L)
-    k <- noisekriging_model(object)
     if (is.data.frame(X_u)) X_u = data.matrix(X_u)
-    if (!is.matrix(X_u)) X_u <- matrix(X_u, ncol = ncol(k$X))
+    if (!is.matrix(X_u)) X_u <- matrix(X_u, ncol = ncol(object$X()))
     if (is.data.frame(y_u)) y_u = data.matrix(y_u)
-    if (!is.matrix(y_u)) y_u <- matrix(y_u, ncol = ncol(k$y))
-    if (ncol(X_u) != ncol(k$X))
-        stop("Object 'X_u' must have ", ncol(k$X), " columns (instead of ",
-             ncol(X_u), ")")
-    if (nrow(y_u) != nrow(X_u))
-        stop("Objects 'X_u' and 'y_u' must have the same number of rows.")
-
+    if (!is.matrix(y_u)) y_u <- matrix(y_u, ncol = 1)
     ## Modify 'object' in the parent environment
     return(noisekriging_update_simulate(object, y_u, noise_u, X_u))
 }
 
 #' Update a \code{NoiseKriging} model object with new points
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object S3 NoiseKriging object.
 #' @param y_u Numeric vector of new responses (output).
@@ -604,20 +590,10 @@ update_simulate.NoiseKriging <- function(object, y_u, noise_u, X_u, ...) {
 #'  border = NA, col = rgb(1, 0, 0, 0.2))
 update.NoiseKriging <- function(object, y_u, noise_u, X_u, refit=TRUE, ...) {
     if (length(L <- list(...)) > 0) warnOnDots(L)
-    k <- noisekriging_model(object)
     if (is.data.frame(X_u)) X_u = data.matrix(X_u)
-    if (!is.matrix(X_u)) X_u <- matrix(X_u, ncol = ncol(k$X))
+    if (!is.matrix(X_u)) X_u <- matrix(X_u, ncol = ncol(object$X()))
     if (is.data.frame(y_u)) y_u = data.matrix(y_u)
-    if (!is.matrix(y_u)) y_u <- matrix(y_u, ncol = ncol(k$y))
-    if (!is.matrix(noise_u)) noise_u <- matrix(noise_u, ncol = ncol(k$y))
-    if (ncol(X_u) != ncol(k$X))
-        stop("Object 'X_u' must have ", ncol(k$X), " columns (instead of ",
-             ncol(X_u), ")")
-    if (nrow(y_u) != nrow(X_u))
-        stop("Objects 'X_u' and 'y_u' must have the same number of rows.")
-    if (nrow(noise_u) != nrow(X_u))
-        stop("Objects 'noise_u' and 'y_u' must have the same number of rows.")
-
+    if (!is.matrix(y_u)) y_u <- matrix(y_u, ncol = 1)
     ## Modify 'object' in the parent environment
     noisekriging_update(object, y_u, noise_u, X_u, refit)
 
@@ -627,7 +603,7 @@ update.NoiseKriging <- function(object, y_u, noise_u, X_u, refit=TRUE, ...) {
 
 #' Save a NoiseKriging Model to a file storage
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object An S3 NoiseKriging object.
 #' @param filename File name to save in.
@@ -663,7 +639,7 @@ save.NoiseKriging <- function(object, filename, ...) {
 
 #' Load a NoiseKriging Model from a file storage
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param filename File name to load from.
 #' @param ... Not used.
@@ -695,7 +671,7 @@ load.NoiseKriging <- function(filename, ...) {
 
 #' Compute Covariance Matrix of NoiseKriging Model
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object An S3 NoiseKriging object.
 #' @param x1 Numeric matrix of input points.
@@ -722,23 +698,16 @@ load.NoiseKriging <- function(filename, ...) {
 #' covMat(k, x1, x2)
 covMat.NoiseKriging <- function(object, x1, x2, ...) {
     if (length(L <- list(...)) > 0) warnOnDots(L)
-    k <- noisekriging_model(object)
     if (is.data.frame(x1)) x1 = data.matrix(x1)
     if (is.data.frame(x2)) x2 = data.matrix(x2)
-    if (!is.matrix(x1)) x1 = matrix(x1, ncol = ncol(k$X))
-    if (!is.matrix(x2)) x2 = matrix(x2, ncol = ncol(k$X))
-    if (ncol(x1) != ncol(k$X))
-        stop("Input x1 must have ", ncol(k$X), " columns (instead of ",
-             ncol(x1), ")")
-    if (ncol(x2) != ncol(k$X))
-        stop("Input x2 must have ", ncol(k$X), " columns (instead of ",
-             ncol(x2), ")")
+    if (!is.matrix(x1)) x1 = matrix(x1, ncol = ncol(object$X()))
+    if (!is.matrix(x2)) x2 = matrix(x2, ncol = ncol(object$X()))
     return(noisekriging_covMat(object, x1, x2))
 }
 
 #' Compute Log-Likelihood of NoiseKriging Model
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object An S3 NoiseKriging object.
 #' @param theta_sigma2 A numeric vector of (positive) range parameters and variance at
@@ -783,12 +752,8 @@ covMat.NoiseKriging <- function(object, x1, x2, ...) {
 logLikelihoodFun.NoiseKriging <- function(object, theta_sigma2,
                                   return_grad = FALSE, bench=FALSE, ...) {
     if (length(L <- list(...)) > 0) warnOnDots(L)
-    k <- noisekriging_model(object)
     if (is.data.frame(theta_sigma2)) theta_sigma2 = data.matrix(theta_sigma2)
-    if (!is.matrix(theta_sigma2)) theta_sigma2 <- matrix(theta_sigma2, ncol = ncol(k$X)+1)
-    if (ncol(theta_sigma2) != ncol(k$X)+1)
-        stop("Input theta_sigma2 must have ", ncol(k$X)+1, " columns (instead of ",
-             ncol(theta_sigma2),")")
+    if (!is.matrix(theta_sigma2)) theta_sigma2 <- matrix(theta_sigma2, ncol = ncol(object$X())+1)
     out <- list(logLikelihood = matrix(NA, nrow = nrow(theta_sigma2)),
                 logLikelihoodGrad = matrix(NA,nrow=nrow(theta_sigma2),
                                            ncol = ncol(theta_sigma2)))
@@ -807,7 +772,7 @@ logLikelihoodFun.NoiseKriging <- function(object, theta_sigma2,
 
 #' Get logLikelihood of NoiseKriging Model
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object An S3 NoiseKriging object.
 #' @param ... Not used.
@@ -836,7 +801,7 @@ logLikelihood.NoiseKriging <- function(object, ...) {
 
 #' Duplicate a NoiseKriging Model
 #'
-#' @author Yann Richet \email{yann.richet@irsn.fr}
+#' @author Yann Richet \email{yann.richet@asnr.fr}
 #'
 #' @param object An S3 NoiseKriging object.
 #' @param ... Not used.
