@@ -1,24 +1,9 @@
-
-f <- function(x) {
-    1.0 - 1.0 / 2.0 * (sin(12.0 * x) / (1.0 + x) +
-                       2.0 * cos(7.0 * x) * x^5 + 0.7)
-}
-
 warnOnDots <- function(dots) {
     warning("Arguments ",
             paste0(names(dots), "=", dots, collapse = ","),
             " are ignored.")
 }
 
-## could be a method ???
-checkNewX <- function(object, X) {
-    
-}
-
-## check that 
-checkNewTheta <- function(object, theta) {
-    
-}
 
 ## XXXY use 'identical' with formula objects seesm cleaner
 formula2regmodel = function(form) {
@@ -54,4 +39,4 @@ as_numeric_matrix = function(x) {
   if (is.data.frame(x))
     return(data.matrix(x))
   stop(paste0("Data no convertible to numeric matrix: ", typeof(x)))
-}
\ No newline at end of file
+}
