@@ -64,8 +64,8 @@ def main():
         package_data={'pylibkriging': []},
         # https://docs.python.org/3/distutils/setupscript.html#installing-additional-files
         data_files=[('lib/site-packages/pylibkriging/shared_libs', extra_libs)],
-        python_requires='>=3.6',
-        # install_requires=get_requirements("requirements.txt"),  # they should be in C++ build environment 
+        python_requires='>=3.7',
+        install_requires=get_requirements("requirements.txt"),  # they should be in C++ build environment
         zip_safe=False,
     )
 
@@ -139,10 +139,11 @@ class CMakeBuild(build_ext):
 
         env = os.environ.copy()
         env['CXXFLAGS'] = env.get('CXXFLAGS', '')
-        print('env:', env['CXXFLAGS'])
 
         if not os.path.exists(self.build_temp):
             os.makedirs(self.build_temp)
+        print(f"environment variables: {env}")
+        print(f"CMAKE arguments: {cmake_args}")
         subprocess.check_call(['cmake', ext.sourcedir] + cmake_args, cwd=self.build_temp, env=env)
         subprocess.check_call(['cmake', '--build', '.'] + build_args, cwd=self.build_temp)
 
