@@ -8,16 +8,6 @@
 ##
 ## ****************************************************************************
 
-## True generic
-setGeneric(name = "logLikelihoodFun",
-           def = function(object, ...) standardGeneric("logLikelihoodFun"))
-
-setGeneric(name = "logMargPostFun",
-           def = function(object, ...) standardGeneric("logMargPostFun"))
-
-setGeneric(name = "leaveOneOutFun",
-           def = function(object, ...) standardGeneric("leaveOneOutFun"))
-
 ## *****************************************************************************
 ##' Coerce an object into an object with S4 class \code{"km"} from the
 ##' \pkg{DiceKriging} package.
@@ -37,6 +27,35 @@ as.km <- function(x, ...) {
     UseMethod("as.km")
 }
 
+## True generic
+setGeneric(name = "covMat",
+                     def = function(object, ...) standardGeneric("covMat"))
+
+## *****************************************************************************
+##' Compute the covariance matrix of a model given in \code{object},
+##' between given set of points.
+##'
+##' @title covariance function
+##'
+##' @param object An object representing a fitted model.
+##' @param ... Further arguments of function (eg. points, range).
+##'
+##' @return The covariance matrix.
+##' @export
+covMat <- function(object, ...) {
+    UseMethod("covMat")
+}
+
+
+setGeneric(name = "logLikelihoodFun",
+                     def = function(object, ...) standardGeneric("logLikelihoodFun"))
+
+setGeneric(name = "logMargPostFun",
+                     def = function(object, ...) standardGeneric("logMargPostFun"))
+
+setGeneric(name = "leaveOneOutFun",
+                     def = function(object, ...) standardGeneric("leaveOneOutFun"))
+
 ## *****************************************************************************
 ##' Compute the leave-One-Out error of a model given in \code{object},
 ##' at a different value of the parameters.
@@ -151,6 +170,21 @@ logMargPost <- function(object, ...) {
     UseMethod("logMargPost")
 }
 
+## *****************************************************************************
+##' Update previous simulate of a model given in
+##' \code{object}.
+##'
+##' @title Update simulation of model on data.
+##'
+##' @param object An object representing a fitted model.
+##' @param ... Further arguments of function
+##'
+##' @return Updated simulation of model output.
+##' @export
+update_simulate <- function(object, ...) {
+    UseMethod("update_simulate")
+}
+
 ## *****************************************************************************
 ##' Duplicate a model given in
 ##' \code{object}.
@@ -182,29 +216,72 @@ fit <- function(object, ...) {
 }
 
 ## *****************************************************************************
-##' Save a model given in
-##' \code{object}.
-##'
-##' @title Save object.
-##'
-##' @param object An object representing a fitted model.
-##' @param ... Ignored.
-##'
-##' @return The saved object.
+##' Save a Kriging Model inside a file. Back to base::save if argument 
+##' is not a Kriging object.
+##' 
+##' @author Yann Richet \email{yann.richet@asnr.fr}
+##' 
+##' @param object An object representing a model.
+##' @param filename A file to save the object.
+##' @param ... Arguments used by base::save.
+##' 
 ##' @export
-save <- function(object, ...) {
-    UseMethod("save")
+save <- function(object=NULL, filename=NULL, ...) {
+    if (is.null(object) || !isTRUE(class(object) %in% c("Kriging","NuggetKriging","NoiseKriging"))) {# back to base::save
+        # warning("Using base::save")
+        if (!is.null(filename)) {
+            if (!is.null(object)) {
+                if ("envir" %in% names(list(...)))
+                    base::save(list=as.character(substitute(object)), file=filename, ...)
+                else
+                    base::save(list=as.character(substitute(object)), file=filename, envir=parent.frame(n=1), ...)
+            } else {
+                if ("envir" %in% names(list(...)))
+                    base::save(..., file=filename)
+                else
+                    base::save(..., file=filename, envir=parent.frame(n=1))
+            }
+        } else {
+            if (!is.null(object)) {
+                if ("envir" %in% names(list(...)))
+                    base::save(list=as.character(substitute(object)), ...)
+                else
+                    base::save(list=as.character(substitute(object)), envir=parent.frame(n=1), ...)
+            } else {
+                if ("envir" %in% names(list(...)))
+                    base::save(...)
+                else
+                    base::save(..., envir=parent.frame(n=1))
+            }
+        }
+    } else {
+        if (is.null(filename) || !is.character(filename))
+            stop("'filename' must be a string")
+        if (length(L <- list(...)) > 0) warnOnDots(L)
+        k_class = class(object)
+        if (is.null(k_class))
+            stop("No class for: ",as.character(substitute(object)))
+        
+        if (k_class=="Kriging")
+            return(save.Kriging(object, filename))
+        else if (k_class=="NuggetKriging")
+            return(save.NuggetKriging(object, filename))
+        else if (k_class=="NoiseKriging")
+            return(save.NoiseKriging(object, filename))
+        else 
+            stop("Unknown Kriging class: ",k_class)
+    }
 }
 
 ## *****************************************************************************
-##' Load any Kriging Model from a file storage.
+##' Load any Kriging Model from a file storage. Back to base::load if not a Kriging object.
 ##'
-##' @author Yann Richet \email{yann.richet@irsn.fr}
+##' @author Yann Richet \email{yann.richet@asnr.fr}
 ##'
 ##' @param filename A file holding any Kriging object.
-##' @param ... Not used.
+##' @param ... Arguments used by base::load.
 ##'
-##' @return The loaded "*"Kriging object.
+##' @return The loaded "*"Kriging object, or nothing if base::load is used (update parent environment).
 ##'
 ##' @export
 ##' 
@@ -217,27 +294,59 @@ save <- function(object, ...) {
 ##' k <- Kriging(y, X, kernel = "matern3_2", objective="LMP")
 ##' print(k)
 ##' 
-##' outfile = tempfile("k.h5") 
+##' outfile = tempfile("k.json") 
 ##' save(k,outfile)
 ##'
 ##' print(load(outfile))
 load <- function(filename, ...) {
-    if (!is.character(filename) ||
-        endsWith(filename,"Rdata") ||
-        endsWith(filename,"RData") ||
-        endsWith(filename,"rdata") ||
-        endsWith(filename,"Rds") ||
-        endsWith(filename,"rds")
-        ) # back to base::load
-        base::load(file=filename,...)
-        #stop("'filename' must be a string")
-    else {
+    if (is.null(filename) ||
+            !is.character(filename) ||
+            endsWith(filename,"Rdata") ||
+            endsWith(filename,"RData") ||
+            endsWith(filename,"rdata") ||
+            endsWith(filename,"Rds") ||
+            endsWith(filename,"rds")
+    ) {# back to base::load
+        # warning("Using base::load")
+        if (! "envir" %in% names(list(...))) {
+            envir = parent.frame(n=2)
+            if (is.null(filename) || !is.character(filename))
+                base::load(...,envir=envir)
+            else 
+                base::load(file=filename,...,envir=envir)
+        } else {
+            if (is.null(filename) || !is.character(filename))
+                base::load(...)
+            else 
+                base::load(file=filename,...)
+        }
+    } else {
         if (length(L <- list(...)) > 0) warnOnDots(L)
-        k = NULL
-        base::try(k <- anykriging_load(filename))
-        if (is.null(k))
-            return(base::load(file=filename,...))
-        else
-            return(k)
+        k_class = NULL
+        base::try(k_class <- class_saved(filename))
+        if (is.null(k_class)) {# back to base::load
+            # warning("Using base::load")
+            if (! "envir" %in% names(list(...))) {
+                envir = parent.frame(n=2)
+                if (is.null(filename) || !is.character(filename))
+                    base::load(...,envir=envir)
+                else 
+                    base::load(file=filename,...,envir=envir)
+            } else {
+                if (is.null(filename) || !is.character(filename))
+                    base::load(...)
+                else 
+                    base::load(file=filename,...)
+            }
+        } else {
+            if (k_class=="Kriging")
+                    return(load.Kriging(filename))
+            else if (k_class=="NuggetKriging")
+                return(load.NuggetKriging(filename))
+            else if (k_class=="NoiseKriging")
+                return(load.NoiseKriging(filename))
+            else 
+                stop("Unknown Kriging class: ",k_class)
+        }
     }
-}
\ No newline at end of file
+}
