@@ -1,4 +1,7 @@
-kernel="gauss"
+#library(rlibkriging, lib.loc="bindings/R/Rlibs")
+#library(testthat)
+#kernel="gauss"
+
 for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   context(paste0("Check LogLikelihood for kernel ",kernel))
   
@@ -21,7 +24,7 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
     arrows(x,llx,x+.1,llx+.1*gllx)
   }
   
-  library(rlibkriging)
+  #library(rlibkriging)
   r <- NuggetKriging(y, X, kernel, parameters=list(nugget=0,is_nugget_estim=TRUE))
   ll2_theta = function(theta) logLikelihoodFun(r,c(theta,alpha0))$logLikelihood
   # second arg is alpha=1 for nugget=0
@@ -29,7 +32,7 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   for (x in seq(0.01,1,,21)){
     envx = new.env()
     ll2x = logLikelihoodFun(r,c(x,alpha0))$logLikelihood
-    gll2x = logLikelihoodFun(r,c(x,alpha0),grad = T)$logLikelihoodGrad[,1]
+    gll2x = logLikelihoodFun(r,c(x,alpha0),return_grad = T)$logLikelihoodGrad[,1]
     arrows(x,ll2x,x+.1,ll2x+.1*gll2x,col='red')
   }
   
@@ -47,7 +50,7 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   for (x in seq(0.01,1,,21)){
     envx = new.env()
     ll2x = logLikelihoodFun(r,c(theta0,x))$logLikelihood
-    gll2x = logLikelihoodFun(r,c(theta0,x),grad = T)$logLikelihoodGrad[,2]
+    gll2x = logLikelihoodFun(r,c(theta0,x),return_grad = T)$logLikelihoodGrad[,2]
     arrows(x,ll2x,x+.1,ll2x+.1*gll2x,col='red')
   }
 
@@ -63,14 +66,14 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   
   test_that(desc="logLik Grad is just good /alpha", 
             expect_equal(
-              logLikelihoodFun(r,c(theta0,x),grad=T)$logLikelihoodGrad[,2]
+              logLikelihoodFun(r,c(theta0,x),return_grad=T)$logLikelihoodGrad[,2]
               ,
               -(logLikelihoodFun(r,c(theta0,x-1e-5))$logLikelihood[1]-logLikelihoodFun(r,c(theta0,x))$logLikelihood[1])/1e-5,
               ,tolerance= 1e-5))
               
   test_that(desc="logLik Grad is the same that DiceKriging one /alpha", 
             expect_equal(
-              logLikelihoodFun(r,c(theta0,x),grad=T)$logLikelihoodGrad[,2]
+              logLikelihoodFun(r,c(theta0,x),return_grad=T)$logLikelihoodGrad[,2]
               ,
               DiceKriging::logLikGrad(c(theta0,x),k,xenv)[2,]
               ,tolerance= precision))
@@ -85,14 +88,14 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
 
   test_that(desc="logLik Grad is just good /theta", 
             expect_equal(
-              logLikelihoodFun(r,c(x,alpha0),grad=T)$logLikelihoodGrad[,1]
+              logLikelihoodFun(r,c(x,alpha0),return_grad=T)$logLikelihoodGrad[,1]
               ,
               (logLikelihoodFun(r,c(x+1e-5,alpha0))$logLikelihood[1]-logLikelihoodFun(r,c(x,alpha0))$logLikelihood[1])/1e-5
               ,tolerance= 1e-3))
 
   test_that(desc="logLik Grad is the same that DiceKriging one /theta", 
             expect_equal(
-              logLikelihoodFun(r,c(x,alpha0),grad=T)$logLikelihoodGrad[,1]
+              logLikelihoodFun(r,c(x,alpha0),return_grad=T)$logLikelihoodGrad[,1]
               ,
               DiceKriging::logLikGrad(c(x,alpha0),k,xenv)[1,]
               ,tolerance= precision))
@@ -133,7 +136,7 @@ for (kernel in c("matern3_2","matern5_2","gauss","exp")) {
   
   test_that(desc="logLik Grad is the same that DiceKriging one", 
             expect_equal(
-              logLikelihoodFun(r,x,grad=T)$logLikelihoodGrad[1,]
+              logLikelihoodFun(r,x,return_grad=T)$logLikelihoodGrad[1,]
               ,
               t(DiceKriging::logLikGrad(x,k,xenv))[1,]
               ,tolerance= precision))
@@ -141,7 +144,7 @@ for (kernel in c("matern3_2","matern5_2","gauss","exp")) {
   eps=0.000001
   test_that(desc="logLik Grad is just good", 
             expect_equal(
-              -logLikelihoodFun(r,x,grad=T)$logLikelihoodGrad[1,]
+              -logLikelihoodFun(r,x,return_grad=T)$logLikelihoodGrad[1,]
               ,
               c( # finite-diff grad
                 (logLikelihoodFun(r,x-c(eps,0,0,0))$logLikelihood[1]-logLikelihoodFun(r,x)$logLikelihood[1])/eps,
