@@ -9,11 +9,6 @@ BASEDIR=$(dirname "$0")
 BASEDIR=$(cd "$BASEDIR" && pwd -P)
 test -f "${BASEDIR}"/loadenv.sh && . "${BASEDIR}"/loadenv.sh 
 
-# Default configuration when used out of travis-ci
-if [[ -n ${TRAVIS_BUILD_DIR:+x} ]]; then
-    cd "${TRAVIS_BUILD_DIR}"
-fi
-
 export LIBKRIGING_PATH=${PWD}/${BUILD_DIR:-build}/installed
 export PATH=${LIBKRIGING_PATH}/bin:${PATH}
 
